@@ -1,6 +1,8 @@
 package MooseX::Getopt::Dashes;
 # ABSTRACT: convert underscores in attribute names to dashes
-our $VERSION = '0.67';
+
+our $VERSION = '0.69';
+
 use Moose::Role;
 with 'MooseX::Getopt';
 use namespace::autoclean;
@@ -31,7 +33,7 @@ MooseX::Getopt::Dashes - convert underscores in attribute names to dashes
 
 =head1 VERSION
 
-version 0.67
+version 0.69
 
 =head1 SYNOPSIS
 
@@ -67,6 +69,17 @@ a L<cmd_flag|MooseX::Getopt::Meta::Attribute/METHODS> argument with
 the command flag you'd like for a given attribute. No underscore to
 dash replacement will be done on the C<cmd_flag>.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Getopt>
+(or L<bug-MooseX-Getopt@rt.cpan.org|mailto:bug-MooseX-Getopt@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
